==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Top/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Kategori");
define("_LVOTES","stemmer");
define("_HITS","Hits");
define("_TOPWELCOME","Velkommen til TOP 10-siden hos");
define("_READSTORIES","mest lste artikler");
define("_COMMENTEDSTORIES","mest kommenterede artikler");
define("_ACTIVECAT","mest aktive kategorier");
define("_READSECTION","mest lste artikler i specialsektionerne");
define("_NEWSSUBMITTERS","mest aktive indsendere");
define("_NEWSSENT","indlg sendt");
define("_VOTEDPOLLS","mest brugte afstemninger");
define("_MOSTACTIVEAUTHORS","mest aktive forfattere");
define("_NEWSPUBLISHED","artikel(er) publiceret");
define("_READREVIEWS","mest lste anmeldelser");
define("_DOWNLOADEDFILES","mest hentede filer");
define("_MOSTREADPAGES","most read pages");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Top/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Kategori");
define("_LVOTES","stemmer");
define("_HITS","Hits");
define("_TOPWELCOME","Velkommen til TOP 10-siden hos");
define("_READSTORIES","mest lste artikler");
define("_COMMENTEDSTORIES","mest kommenterede artikler");
define("_ACTIVECAT","mest aktive kategorier");
define("_READSECTION","mest lste artikler i specialsektionerne");
define("_NEWSSUBMITTERS","mest aktive indsendere");
define("_NEWSSENT","indlg sendt");
define("_VOTEDPOLLS","mest brugte afstemninger");
define("_MOSTACTIVEAUTHORS","mest aktive forfattere");
define("_NEWSPUBLISHED","artikel(er) publiceret");
define("_READREVIEWS","mest lste anmeldelser");
define("_DOWNLOADEDFILES","mest hentede filer");
define("_MOSTREADPAGES","most read pages");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>
